@@ -70,7 +70,11 @@ NAME is the instance name.  If nil, auto-generates one."
       ;; Send the claude command
       (with-current-buffer buffer
         (vterm-send-string magnus-claude-executable)
-        (vterm-send-return))
+        (run-with-timer 0.1 nil
+                        (lambda ()
+                          (when (buffer-live-p buffer)
+                            (with-current-buffer buffer
+                              (vterm-send-return))))))
       ;; Set up process sentinel
       (magnus-process--setup-sentinel instance buffer)
       ;; Send onboarding message after Claude starts
@@ -504,7 +508,11 @@ Replaces slashes, spaces, and tildes with hyphens."
             (vterm-send-string (format "%s --resume %s"
                                        magnus-claude-executable session-id))
           (vterm-send-string magnus-claude-executable))
-        (vterm-send-return))
+        (run-with-timer 0.1 nil
+                        (lambda ()
+                          (when (buffer-live-p buffer)
+                            (with-current-buffer buffer
+                              (vterm-send-return))))))
       ;; Set up process sentinel
       (magnus-process--setup-sentinel instance buffer)
       buffer)))
@@ -677,11 +685,14 @@ PARTIAL is the incomplete line from previous call.  Returns new partial."
     (dolist (line complete-lines)
       (when (and (not (string-empty-p line))
                  (string-prefix-p "{" (string-trim line)))
-        (condition-case nil
+        (condition-case err
             (let* ((json (json-parse-string (string-trim line) :object-type 'alist))
                    (type (alist-get 'type json)))
               (magnus-process--headless-handle-event instance proc json type))
-          (error nil))))
+          (error
+           (message "Magnus: headless event error for %s: %s"
+                    (magnus-instance-name instance)
+                    (error-message-string err))))))
     remainder))
 
 (defun magnus-process--headless-handle-event (instance proc json type)
