@@ -4,8 +4,8 @@
 
 ;; Author: Hrishikesh S <hrish2006@gmail.com>
 ;; Maintainer: Hrishikesh S <hrish2006@gmail.com>
-;; Package-Version: 20260226.710
-;; Package-Revision: be19e7edfd6c
+;; Package-Version: 20260228.525
+;; Package-Revision: 1b23d7cb1598
 ;; Package-Requires: ((emacs "28.1") (vterm "0.0.2") (transient "0.4.0"))
 ;; Keywords: tools, processes, convenience
 ;; URL: https://github.com/hrishikeshs/magnus
@@ -565,7 +565,8 @@ archives them, saves state, and reinstalls the package."
          (concat "Magnus is upgrading in 2 minutes. Save your work and "
                  "update your memory file now — write in first person, as "
                  "yourself. This session will be archived and you can be "
-                 "resurrected after the upgrade.")))
+                 "resurrected after the upgrade.")
+         "Magnus"))
       (message "Magnus: warned %d agent%s. Upgrading in 120 seconds..."
                (length active)
                (if (= (length active) 1) "" "s"))
